package com.aucma.base.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.aucma.base.mapper.QualityTraceMapper;
import com.aucma.base.domain.QualityTrace;
import com.aucma.base.service.IQualityTraceService;

@Service
public class QualityTraceServiceImpl implements IQualityTraceService {
    @Autowired
    private QualityTraceMapper qualityTraceMapper;

    @Override
    public QualityTrace selectQualityTraceByObjId(Long objId) {
        return qualityTraceMapper.selectQualityTraceByObjId(objId);
    }

    @Override
    public List<QualityTrace> selectQualityTraceList(QualityTrace qualityTrace) {
        return qualityTraceMapper.selectQualityTraceList(qualityTrace);
    }

    @Override
    public int insertQualityTrace(QualityTrace qualityTrace) {
        return qualityTraceMapper.insertQualityTrace(qualityTrace);
    }

    @Override
    public int updateQualityTrace(QualityTrace qualityTrace) {
        return qualityTraceMapper.updateQualityTrace(qualityTrace);
    }

    @Override
    public int deleteQualityTraceByObjIds(Long[] objIds) {
        return qualityTraceMapper.deleteQualityTraceByObjIds(objIds);
    }

    @Override
    public int deleteQualityTraceByObjId(Long objId) {
        return qualityTraceMapper.deleteQualityTraceByObjId(objId);
    }
}
