package com.aucma.base.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.aucma.common.utils.DateUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.aucma.common.annotation.Log;
import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.enums.BusinessType;
import com.aucma.base.domain.QualityTrace;
import com.aucma.base.service.IQualityTraceService;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.common.core.page.TableDataInfo;

@RestController
@RequestMapping("/base/qualityTrace" )
public class QualityTraceController extends BaseController {
    @Autowired
    private IQualityTraceService qualityTraceService;

    @PreAuthorize("@ss.hasPermi('base:qualityTrace:list')" )
    @GetMapping("/list" )
    public TableDataInfo list(QualityTrace qualityTrace) {
        startPage();
        List<QualityTrace> list = qualityTraceService.selectQualityTraceList(qualityTrace);
        return getDataTable(list);
    }

    @PreAuthorize("@ss.hasPermi('base:qualityTrace:export')" )
    @Log(title = "品质质量追溯" , businessType = BusinessType.EXPORT)
    @PostMapping("/export" )
    public void export(HttpServletResponse response, QualityTrace qualityTrace) {
        List<QualityTrace> list = qualityTraceService.selectQualityTraceList(qualityTrace);
        ExcelUtil<QualityTrace> util = new ExcelUtil<QualityTrace>(QualityTrace. class);
        util.exportExcel(response, list, "品质质量追溯数据" );
    }

    @PreAuthorize("@ss.hasPermi('base:qualityTrace:query')" )
    @GetMapping(value = "/{objId}" )
    public AjaxResult getInfo(@PathVariable("objId" ) Long objId) {
        return success(qualityTraceService.selectQualityTraceByObjId(objId));
    }

    @PreAuthorize("@ss.hasPermi('base:qualityTrace:add')" )
    @Log(title = "品质质量追溯" , businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody QualityTrace qualityTrace) {
        qualityTrace.setCreatedTime(DateUtils.getNowDate());
        return toAjax(qualityTraceService.insertQualityTrace(qualityTrace));
    }

    @PreAuthorize("@ss.hasPermi('base:qualityTrace:edit')" )
    @Log(title = "品质质量追溯" , businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody QualityTrace qualityTrace) {
        qualityTrace.setUpdatedTime(DateUtils.getNowDate());
        return toAjax(qualityTraceService.updateQualityTrace(qualityTrace));
    }

    @PreAuthorize("@ss.hasPermi('base:qualityTrace:remove')" )
    @Log(title = "品质质量追溯" , businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}" )
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(qualityTraceService.deleteQualityTraceByObjIds(objIds));
    }

    @PreAuthorize("@ss.hasPermi('base:qualityTrace:list')" )
    @GetMapping("/getList" )
    public TableDataInfo getList(QualityTrace qualityTrace) {
        List<QualityTrace> list = qualityTraceService.selectQualityTraceList(qualityTrace);
        return getDataTable(list);
    }
}
